#!/bin/bash

POL_PATH="/usr/share/playonlinux/lib"

addcache ()
{
    CACHE=`echo -e "$CACHE\n$1"`
}

flush ()
{
    echo "$CACHE"
    CACHE=""
}

gensource_file ()
{
    IFS=$'\n'
    OLD_CMD=""
    DOCUMENTED="no"
    echo "/// @file $(basename $1)"
    for LINE in `grep -hP "^((.*\(\))|[\t ]#)" $1 | sed -e "s/.*()/function & {}/"`; do
        CMD=`echo -n "$LINE" | sed -ne "/^function/p"`
        COMMENT=`echo -n "$LINE" | sed -e "s/[\t ]*##* *\(.*\)/\1/"`

        if test "$CMD" != ""; then
            flush
            test "$DOCUMENTED" = "yes" && echo "$OLD_CMD"
            OLD_CMD="$CMD"
            CMD=""
            DOCUMENTED="no"
        elif test "$COMMENT" != ""; then
            USAGE=`echo "$COMMENT" | sed -ne 's/Usage[ :]* \([a-zA-Z0-9_]*\) */\1 (/p'`
            if test "$USAGE" != ""; then
                USAGE=`echo "$USAGE" | sed -e "s/\] \[/, var /g" | sed -e "s/\[/var /g" | sed -e "s/\]//g"`
                OLD_CMD="function $USAGE) { /* Some code hiden here */ }"
            elif test "$DOCUMENTED" = "no"; then
                addcache "/// @brief $COMMENT"
            else
                COMMENT=`echo "$COMMENT" | sed -e "s/Return/@return &/"`
                addcache "/// $COMMENT"
            fi
            test "$DOCUMENTED" = "no" && DOCUMENTED="yes"
        else
            echo "Bad Line: $LINE" >&2
        fi
    done
    echo "$OLD_CMD"
}

gensource ()
{
    IFS=$'\n'
    for FILE in $POL_PATH/*; do
        echo "$FILE"
        gensource_file "$FILE" > sources/$(basename $FILE)
    done
}

test "$(dirname $0)" = "$0" || cd $(dirname $0)

mkdir -p sources
gensource
doxygen

